@@ -6,4 +6,7 @@ GEO_WIDGET_DEFAULT_LOCATION = getattr(
 GEO_WIDGET_EMPTY_LOCATION = getattr(settings, "GEO_WIDGET_EMPTY_LOCATION", False)
 GEO_WIDGET_ZOOM = getattr(settings, "GEO_WIDGET_ZOOM", 7)
 GOOGLE_MAPS_V3_APIKEY = getattr(settings, "GOOGLE_MAPS_V3_APIKEY", None)
+GOOGLE_MAPS_V3_APIKEY_CALLBACK = getattr(
+    settings, "GOOGLE_MAPS_V3_APIKEY_CALLBACK", None
+)
 GOOGLE_MAPS_V3_LANGUAGE = getattr(settings, "GOOGLE_MAPS_V3_LANGUAGE", "en")
